@@ -108,8 +108,7 @@ class History:
             ]
         else:
             raise TypeError(
-                "history indices must be integers "
-                "or slices, not {}".format(type(item))
+                "history indices must be integers " f"or slices, not {type(item)}"
             )
 
     def __setitem__(self, *args):
@@ -174,6 +173,22 @@ class History:
         """
         pass
 
+    def delete(self, pattern):
+        """Deletes the history of the current session for commands that match
+        a user-provided pattern.
+
+        Parameters
+        ----------
+        pattern: str
+            The regex pattern to match commands against.
+
+        Returns
+        -------
+        int
+            The number of commands deleted from history.
+        """
+        pass
+
     @functools.cached_property
     def ignore_regex(self):
         compiled_regex = None
