@@ -11,7 +11,7 @@ class DummyHistory(History):
         pass
 
     def items(self, newest_first=False):
-        yield {"inp": "dummy in action", "ts": 1464652800, "ind": 0}
+        yield {"inp": "# dummy history backend in action", "ts": 1464652800, "ind": 0}
 
     def all_items(self, newest_first=False):
         return self.items(newest_first=newest_first)
