@@ -1,10 +1,9 @@
 """Xonsh color styling tools that simulate pygments, when it is unavailable."""
-import builtins
 from collections import defaultdict
 
-from xonsh.platform import HAS_PYGMENTS
-from xonsh.lazyasd import LazyObject
 from xonsh.color_tools import RE_BACKGROUND, iscolor, warn_deprecated_no_color
+from xonsh.lazyasd import LazyObject
+from xonsh.platform import HAS_PYGMENTS
 from xonsh.tools import FORMATTER
 
 
@@ -16,7 +15,7 @@ class _TokenType(tuple):
     See https://bitbucket.org/birkenfeld/pygments-main/raw/05818a4ef9891d9ac22c851f7b3ea4b4fce460ab/AUTHORS
     """
 
-    parent = None
+    parent: "_TokenType|None" = None
 
     def split(self):
         buf = []
@@ -64,9 +63,11 @@ def partial_color_tokenize(template):
     of tuples mapping the token to the string which has that color.
     These sub-strings maybe templates themselves.
     """
-    if HAS_PYGMENTS and builtins.__xonsh__.shell is not None:
-        styles = __xonsh__.shell.shell.styler.styles
-    elif builtins.__xonsh__.shell is not None:
+    from xonsh.built_ins import XSH
+
+    if HAS_PYGMENTS and XSH.shell is not None:
+        styles = XSH.shell.shell.styler.styles
+    elif XSH.shell is not None:
         styles = DEFAULT_STYLE_DICT
     else:
         styles = None
@@ -172,7 +173,7 @@ def norm_name(name):
 def style_as_faded(template: str) -> str:
     """Remove the colors from the template string and style as faded."""
     tokens = partial_color_tokenize(template)
-    without_color = "".join([sect for _, sect in tokens])
+    without_color = "".join([str(sect) for _, sect in tokens])
     return "{RESET}{#d3d3d3}" + without_color + "{RESET}"
 
 
@@ -181,8 +182,6 @@ DEFAULT_STYLE_DICT = LazyObject(
         lambda: "",
         {
             Token: "",
-            Token.Aborted: "ansibrightblack",
-            Token.AutoSuggestion: "ansibrightblack",
             Token.Color.BACKGROUND_BLACK: "bg:ansiblack",
             Token.Color.BACKGROUND_BLUE: "bg:ansiblue",
             Token.Color.BACKGROUND_CYAN: "bg:ansicyan",
@@ -314,9 +313,6 @@ DEFAULT_STYLE_DICT = LazyObject(
             Token.Literal.String.Regex: "ansimagenta",
             Token.Literal.String.Single: "",
             Token.Literal.String.Symbol: "ansiyellow",
-            Token.Menu.Completions: "bg:ansigray ansiblack",
-            Token.Menu.Completions.Completion: "",
-            Token.Menu.Completions.Completion.Current: "bg:ansibrightblack ansiwhite",
             Token.Name: "",
             Token.Name.Attribute: "ansibrightyellow",
             Token.Name.Builtin: "ansigreen",
@@ -342,24 +338,18 @@ DEFAULT_STYLE_DICT = LazyObject(
             Token.Operator.Word: "bold ansimagenta",
             Token.Other: "",
             Token.Punctuation: "",
-            Token.Scrollbar: "bg:ansibrightblack",
-            Token.Scrollbar.Arrow: "bg:ansiblack ansiwhite bold",
-            Token.Scrollbar.Button: "bg:ansiblack",
             Token.Text: "",
             Token.Text.Whitespace: "ansigray",
+            Token.PTK.Aborting: "ansibrightblack",
+            Token.PTK.AutoSuggestion: "ansibrightblack",
+            Token.PTK.CompletionMenu: "bg:ansigray ansiblack",
+            Token.PTK.CompletionMenu.Completion: "",
+            Token.PTK.CompletionMenu.Completion.Current: "bg:ansibrightblack ansiwhite",
+            Token.PTK.Scrollbar.Arrow: "bg:ansiblack ansiwhite bold",
+            Token.PTK.Scrollbar.Background: "bg:ansibrightblack",
+            Token.PTK.Scrollbar.Button: "bg:ansiblack",
         },
     ),
     globals(),
     "DEFAULT_STYLE_DICT",
 )
-
-PTK2_STYLE = {
-    "completion-menu": "bg:ansigray ansiblack",
-    "completion-menu.completion": "",
-    "completion-menu.completion.current": "bg:ansibrightblack ansiwhite",
-    "scrollbar.background": "bg:ansibrightblack",
-    "scrollbar.arrow": "bg:ansiblack ansiwhite bold",
-    "scrollbar.button": "bg:ansiblack",
-    "auto-suggestion": "ansibrightblack",
-    "aborting": "ansibrightblack",
-}
