@@ -3,7 +3,7 @@ import os
 import re
 import typing as tp
 
-RENDERERS: tp.List[tp.Callable] = []
+RENDERERS: list[tp.Callable] = []
 
 
 def renderer(f):
